#include <avr/io.h>
#include <avr/pgmspace.h>
#include <util/delay.h>

#define OUT_BIT 1	// PORT B pin for output
#define DELAY 32	// ms per transition
#define PREAMBLE 320	// preamble transitions
#define TAIL 160	// tail unmodulated CW periods
#define PAUSE 2000	// pause between repeats

#include "message.h"

void key() {
	DDRB |= OUT_BIT; // enable output pin
	PORTB = 0;
}

void sendBit(char bit) {
	if(!bit) PORTB ^= OUT_BIT;	// zeros are sent as a phase transition
	_delay_ms(DELAY);
}

void preamble() {
	int i;
	for(i = 0; i < PREAMBLE; i++) sendBit(0);
}

void tail() {
	PORTB |= OUT_BIT;
	_delay_ms(DELAY * TAIL);
}

void unkey() {
	DDRB &= ~OUT_BIT;		// tristate output pin
}

void sendMessage() {
	int i,j;
	for(i = 0; i < LENGTH; i++) {
		unsigned char byte = pgm_read_byte(&varicodeData[i]);
		for(j = 0; j < 8; j++) {
			sendBit(byte & (1 << (7 - j)));
		}
	}
}

int main() {

	while(1) {
		key();
		preamble();
		sendMessage();
		tail();
		unkey();

		_delay_ms(PAUSE);
	}
	
	return 0;  // unreached
}
